@@ -1,12 +1,7 @@
 from pydantic import BaseModel
 from typing import Optional, List
 from enum import IntEnum
-from agricore_sp_models.import_models import ProductGroupJsonDTO, FADNProductJsonDTO, PolicyJsonDTO
-
-class OrganicProductionType(IntEnum):
-    Conventional = 0
-    Organic = 1
-    Undetermined = 2
+from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO
     
 class AgriculturalProduction(BaseModel):
     id: Optional[int] = None
@@ -214,8 +209,6 @@ class LivestockDTO(BaseModel):
     milkSellingPrice: float
     variableCosts: float
 
-
-
 class HolderInfoDTO(BaseModel):
     holderAge: int
     holderSuccessorsAge: int
