@@ -1,4 +1,4 @@
-from agricore_sp_models.agricore_sp_models import OrganicProductionType
+from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO
 from pydantic import BaseModel, Field
 from typing import List
 
@@ -110,26 +110,6 @@ class FarmJsonDTO(BaseModel):
     farmYearSubsidies: List[FarmYearSubsidyDTO]
     landTransactions: List[LandTransactionJsonDTO]
     
-class FADNProductJsonDTO(BaseModel):
-    fadnIdentifier: str
-    description: str
-    productType: str
-    arable: bool
-    
-class PolicyJsonDTO(BaseModel):
-    policyIdentifier: str
-    isCoupled: bool
-    policyDescription: str
-        
-class ProductGroupJsonDTO(BaseModel):
-    name: str
-    productType: str
-    originalNameDatasource: str
-    productsIncludedInOriginalDataset: str
-    modelSpecificCategories: List[str]
-    organic: OrganicProductionType
-    fadnProducts: List[FADNProductJsonDTO]
-    policies: List[PolicyJsonDTO]
     
 class PopulationJsonDTO(BaseModel):
     description: str = ""
